@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,8 +7,8 @@
 #include "smtpmailtransportplugin.h"
 #include "smtpconfigdialog.h"
 #include "smtpjob.h"
-#include <KPluginFactory>
 #include <KLocalizedString>
+#include <KPluginFactory>
 
 K_PLUGIN_CLASS_WITH_JSON(SMTPMailTransportPlugin, "smtpmailtransport.json")
 
@@ -34,9 +34,8 @@ QVector<MailTransport::TransportAbstractPluginInfo> SMTPMailTransportPlugin::nam
 
 bool SMTPMailTransportPlugin::configureTransport(const QString &identifier, MailTransport::Transport *transport, QWidget *parent)
 {
-    Q_UNUSED(identifier);
-    QPointer<MailTransport::SmtpConfigDialog> transportConfigDialog
-        = new MailTransport::SmtpConfigDialog(transport, parent);
+    Q_UNUSED(identifier)
+    QPointer<MailTransport::SmtpConfigDialog> transportConfigDialog = new MailTransport::SmtpConfigDialog(transport, parent);
     transportConfigDialog->setWindowTitle(i18nc("@title:window", "Configure account"));
     bool okClicked = (transportConfigDialog->exec() == QDialog::Accepted);
     delete transportConfigDialog;
@@ -45,7 +44,7 @@ bool SMTPMailTransportPlugin::configureTransport(const QString &identifier, Mail
 
 MailTransport::TransportJob *SMTPMailTransportPlugin::createTransportJob(MailTransport::Transport *t, const QString &identifier)
 {
-    Q_UNUSED(identifier);
+    Q_UNUSED(identifier)
     return new MailTransport::SmtpJob(t, this);
 }
 
