@@ -1,14 +1,14 @@
 /*
-    SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "transportpluginmanager.h"
 #include "mailtransport_debug.h"
-#include <kpluginmetadata.h>
-#include <KPluginLoader>
 #include <KPluginFactory>
+#include <KPluginLoader>
+#include <kpluginmetadata.h>
 
 #include <MailTransport/TransportAbstractPlugin>
 
@@ -24,7 +24,8 @@ public:
     MailTransport::TransportAbstractPlugin *plugin = nullptr;
 };
 
-namespace {
+namespace
+{
 QString pluginVersion()
 {
     return QStringLiteral("1.0");
@@ -44,6 +45,7 @@ public:
     QVector<MailTransport::TransportAbstractPlugin *> pluginsList() const;
     QVector<MailTransportPluginInfo> mPluginList;
     bool initializePlugins();
+
 private:
     TransportPluginManager *q;
 };
