@@ -6,13 +6,13 @@
 
 #include "transportmanager.h"
 #include "mailtransport_defs.h"
+#include "plugins/transportabstractplugin.h"
+#include "plugins/transportpluginmanager.h"
 #include "transport.h"
 #include "transport_p.h"
 #include "transportjob.h"
 #include "transporttype.h"
 #include "transporttype_p.h"
-#include "plugins/transportpluginmanager.h"
-#include "plugins/transportabstractplugin.h"
 #include "widgets/addtransportdialogng.h"
 #include <MailTransport/TransportAbstractPlugin>
 
@@ -25,20 +25,22 @@
 #include <QRegularExpression>
 #include <QStringList>
 
+#include "mailtransport_debug.h"
 #include <KConfig>
 #include <KConfigGroup>
-#include "mailtransport_debug.h"
 #include <KEMailSettings>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <Kdelibs4ConfigMigrator>
-
+#include <qt5keychain/keychain.h>
+using namespace QKeychain;
 #include <KWallet>
 
 using namespace MailTransport;
 using namespace KWallet;
 
-namespace MailTransport {
+namespace MailTransport
+{
 /**
  * Private class that helps to provide binary compatibility between releases.
  * @internal
@@ -60,13 +62,13 @@ public:
     KConfig *config = nullptr;
     QList<Transport *> transports;
     TransportType::List types;
-    bool myOwnChange;
-    bool appliedChange;
+    bool myOwnChange = false;
+    bool appliedChange = false;
     KWallet::Wallet *wallet = nullptr;
-    bool walletOpenFailed;
-    bool walletAsyncOpen;
-    int defaultTransportId;
-    bool isMainInstance;
+    bool walletOpenFailed = false;
+    bool walletAsyncOpen = false;
+    int defaultTransportId = -1;
+    bool isMainInstance = false;
     QList<TransportJob *> walletQueue;
     TransportManager *const q;
 
@@ -90,7 +92,8 @@ public:
 class StaticTransportManager : public TransportManager
 {
 public:
-    StaticTransportManager() : TransportManager()
+    StaticTransportManager()
+        : TransportManager()
     {
     }
 };
@@ -111,28 +114,16 @@ TransportManager::TransportManager()
     migrate.migrate();
 
     qAddPostRoutine(destroyStaticTransportManager);
-    d->myOwnChange = false;
-    d->appliedChange = false;
-    d->wallet = nullptr;
-    d->walletOpenFailed = false;
-    d->walletAsyncOpen = false;
-    d->defaultTransportId = -1;
     d->config = new KConfig(QStringLiteral("mailtransports"));
 
-    QDBusConnection::sessionBus().registerObject(DBUS_OBJECT_PATH, this,
-                                                 QDBusConnection::ExportScriptableSlots
-                                                 |QDBusConnection::ExportScriptableSignals);
+    QDBusConnection::sessionBus().registerObject(DBUS_OBJECT_PATH, this, QDBusConnection::ExportScriptableSlots | QDBusConnection::ExportScriptableSignals);
 
-    QDBusServiceWatcher *watcher
-        = new QDBusServiceWatcher(DBUS_SERVICE_NAME, QDBusConnection::sessionBus(),
-                                  QDBusServiceWatcher::WatchForUnregistration, this);
+    QDBusServiceWatcher *watcher = new QDBusServiceWatcher(DBUS_SERVICE_NAME, QDBusConnection::sessionBus(), QDBusServiceWatcher::WatchForUnregistration, this);
     connect(watcher, &QDBusServiceWatcher::serviceUnregistered, this, [this]() {
         d->dbusServiceUnregistered();
     });
 
-    QDBusConnection::sessionBus().connect(QString(), QString(),
-                                          DBUS_INTERFACE_NAME, DBUS_CHANGE_SIGNAL,
-                                          this, SLOT(slotTransportsChanged()));
+    QDBusConnection::sessionBus().connect(QString(), QString(), DBUS_INTERFACE_NAME, DBUS_CHANGE_SIGNAL, this, SLOT(slotTransportsChanged()));
 
     d->isMainInstance = QDBusConnection::sessionBus().registerService(DBUS_SERVICE_NAME);
 
@@ -181,7 +172,7 @@ Transport *TransportManager::transportByName(const QString &name, bool def) cons
     return nullptr;
 }
 
-QList< Transport * > TransportManager::transports() const
+QList<Transport *> TransportManager::transports() const
 {
     return d->transports;
 }
@@ -370,10 +361,9 @@ void TransportManager::setDefaultTransport(int id)
 
 void TransportManager::removePasswordFromWallet(int id)
 {
-    Wallet *currentWallet = wallet();
-    if (currentWallet) {
-        currentWallet->removeEntry(QString::number(id));
-    }
+    auto deleteJob = new DeletePasswordJob(WALLET_FOLDER);
+    deleteJob->setKey(QString::number(id));
+    deleteJob->start();
 }
 
 void TransportManager::removeTransport(int id)
@@ -390,12 +380,11 @@ void TransportManager::removeTransport(int id)
 
     d->transports.removeAll(t);
     d->validateDefault();
-    QString group = t->currentGroup();
+    const QString group = t->currentGroup();
     if (t->storePassword()) {
-        Wallet *currentWallet = wallet();
-        if (currentWallet) {
-            currentWallet->removeEntry(QString::number(t->id()));
-        }
+        auto deleteJob = new DeletePasswordJob(WALLET_FOLDER);
+        deleteJob->setKey(QString::number(t->id()));
+        deleteJob->start();
     }
     delete t;
     d->config->deleteGroup(group);
@@ -407,20 +396,21 @@ void TransportManagerPrivate::readConfig()
     QList<Transport *> oldTransports = transports;
     transports.clear();
 
-    QRegularExpression re(QStringLiteral("^Transport (.+)$"));
+    static QRegularExpression re(QStringLiteral("^Transport (.+)$"));
     const QStringList groups = config->groupList().filter(re);
     for (const QString &s : groups) {
-        QRegularExpressionMatch match = re.match(s);
+        const QRegularExpressionMatch match = re.match(s);
         if (!match.hasMatch()) {
             continue;
         }
         Transport *t = nullptr;
         // see if we happen to have that one already
+        const QString capturedString = match.captured(1);
+        const QString checkString = QLatin1String("Transport ") + capturedString;
         for (Transport *old : oldTransports) {
-            if (old->currentGroup() == QLatin1String("Transport ") + match.captured(1)) {
+            if (old->currentGroup() == checkString) {
                 qCDebug(MAILTRANSPORT_LOG) << "reloading existing transport:" << s;
                 t = old;
-                t->d->passwordNeedsUpdateFromWallet = true;
                 t->load();
                 oldTransports.removeAll(old);
                 break;
@@ -428,7 +418,7 @@ void TransportManagerPrivate::readConfig()
         }
 
         if (!t) {
-            t = new Transport(match.captured(1));
+            t = new Transport(capturedString);
         }
         if (t->id() <= 0) {
             t->setId(createId());
@@ -439,7 +429,6 @@ void TransportManagerPrivate::readConfig()
 
     qDeleteAll(oldTransports);
     oldTransports.clear();
-
     // read default transport
     KConfigGroup group(config, "General");
     defaultTransportId = group.readEntry("default-transport", 0);
@@ -620,8 +609,8 @@ void TransportManager::loadPasswordsAsync()
             window = qApp->topLevelWidgets().first()->winId();
         }
 
-        d->wallet = Wallet::openWallet(Wallet::NetworkWallet(), window,
-                                       Wallet::Asynchronous);
+        d->wallet = Wallet::openWallet(Wallet::NetworkWallet(), window, Wallet::Asynchronous);
+        // Already async. It will be easy to port to qt5keychain
         if (d->wallet) {
             connect(d->wallet, &KWallet::Wallet::walletOpened, this, [this](bool status) {
                 d->slotWalletOpened(status);
@@ -690,17 +679,18 @@ void TransportManagerPrivate::migrateToWallet()
     }
 
     // ask user if he wants to migrate
-    int result = KMessageBox::questionYesNoList(
-        nullptr,
-        i18n("The following mail transports store their passwords in an "
-             "unencrypted configuration file.\nFor security reasons, "
-             "please consider migrating these passwords to KWallet, the "
-             "KDE Wallet management tool,\nwhich stores sensitive data "
-             "for you in a strongly encrypted file.\n"
-             "Do you want to migrate your passwords to KWallet?"),
-        names, i18n("Question"),
-        KGuiItem(i18n("Migrate")), KGuiItem(i18n("Keep")),
-        QStringLiteral("WalletMigrate"));
+    int result = KMessageBox::questionYesNoList(nullptr,
+                                                i18n("The following mail transports store their passwords in an "
+                                                     "unencrypted configuration file.\nFor security reasons, "
+                                                     "please consider migrating these passwords to KWallet, the "
+                                                     "KDE Wallet management tool,\nwhich stores sensitive data "
+                                                     "for you in a strongly encrypted file.\n"
+                                                     "Do you want to migrate your passwords to KWallet?"),
+                                                names,
+                                                i18n("Question"),
+                                                KGuiItem(i18n("Migrate")),
+                                                KGuiItem(i18n("Keep")),
+                                                QStringLiteral("WalletMigrate"));
     if (result != KMessageBox::Yes) {
         return;
     }
