@@ -15,7 +15,8 @@ class KJob;
 class QLineEdit;
 class KTextEdit;
 
-namespace MailTransport {
+namespace MailTransport
+{
 class MessageQueueJob;
 }
 
