@@ -1,20 +1,7 @@
 /*
-    Copyright 2009 Constantin Berzan <exit3219@gmail.com>
+    SPDX-FileCopyrightText: 2009 Constantin Berzan <exit3219@gmail.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef MAILTRANSPORT_TRANSPORTATTRIBUTE_H
@@ -24,7 +11,8 @@
 
 #include <attribute.h>
 
-namespace MailTransport {
+namespace MailTransport
+{
 class Transport;
 
 /**
@@ -59,7 +47,7 @@ public:
       Returns the transport id to use for sending this message.
       @see TransportManager.
     */
-    int transportId() const;
+    Q_REQUIRED_RESULT int transportId() const;
 
     /**
       Returns the transport object corresponding to the transport id contained
